==> insights-core-3.0.209.tar.gz: insights-core-3.0.209/insights/parsers/puppet_ca_cert_expire_date.py <==
"""
PuppetCertExpireDate - command ``openssl x509 -in /etc/puppetlabs/puppet/ssl/ca/ca_crt.pem -enddate -noout``
============================================================================================================

The PuppetCertExpireDate parser reads the output of
``openssl x509 -in /etc/puppetlabs/puppet/ssl/ca/ca_crt.pem -enddate -noout``.

Sample output of ``openssl x509 -in /etc/puppetlabs/puppet/ssl/ca/ca_crt.pem -enddate -noout``::

    notAfter=Dec  4 07:04:05 2035 GMT

Examples::

    >>> type(date_info)
    <class 'insights.parsers.puppet_ca_cert_expire_date.PuppetCertExpireDate'>
    >>> date_info.expire_date
    datetime.datetime(2035, 12, 4, 7, 4, 5)

"""
from datetime import datetime

from insights import parser, CommandParser
from insights.specs import Specs
from insights.parsers import SkipException, ParseException


@parser(Specs.puppet_ca_cert_expire_date)
class PuppetCertExpireDate(CommandParser):
    """
    Read the ``openssl x509 -in /etc/puppetlabs/puppet/ssl/ca/ca_crt.pem -enddate -noout``
    and set the date to property ``expire_date``.

    Attributes:
        expire_date (datetime): The date when the puppet ca cert will be expired
    """

    def parse_content(self, content):
        if len(content) == 1 and content[0].startswith('notAfter='):
            date_format = '%b %d %H:%M:%S %Y %Z'
            date_str = content[0].split('=', 1)[1]
            try:
                self.expire_date = datetime.strptime(date_str, date_format)
            except Exception:
                raise ParseException("Can not parse the date format")
        else:
            raise SkipException("Cannot get the puppet ca cert expire info")

==> insights-core-3.0.277.tar.gz: insights-core-3.0.277/insights/parsers/puppet_ca_cert_expire_date.py <==
"""
PuppetCertExpireDate - command ``openssl x509 -in /etc/puppetlabs/puppet/ssl/ca/ca_crt.pem -enddate -noout``
============================================================================================================

The PuppetCertExpireDate parser reads the output of
``openssl x509 -in /etc/puppetlabs/puppet/ssl/ca/ca_crt.pem -enddate -noout``.

Sample output of ``openssl x509 -in /etc/puppetlabs/puppet/ssl/ca/ca_crt.pem -enddate -noout``::

    notAfter=Dec  4 07:04:05 2035 GMT

Examples::

    >>> type(date_info)
    <class 'insights.parsers.puppet_ca_cert_expire_date.PuppetCertExpireDate'>
    >>> date_info['notAfter'].datetime
    datetime.datetime(2035, 12, 4, 7, 4, 5)

"""

from insights import parser
from insights.specs import Specs
from insights.parsers import SkipException
from insights.parsers.ssl_certificate import CertificateInfo


@parser(Specs.puppet_ca_cert_expire_date)
class PuppetCertExpireDate(CertificateInfo):
    """
    .. note::
        Please refer to its super-class :class:`insights.parsers.ssl_certificate.CertificateInfo` for more
        details.

    .. warning::
        The attribute expire_date is deprecated, please get the value from the dictionary directly instead.

    Read the ``openssl x509 -in /etc/puppetlabs/puppet/ssl/ca/ca_crt.pem -enddate -noout``
    and set the date to property ``expire_date``.

    Attributes:
        expire_date (datetime): The date when the puppet ca cert will be expired

    Raises:
        SkipException: when notAfter isn't in the output
    """

    def parse_content(self, content):
        super(PuppetCertExpireDate, self).parse_content(content)
        if 'notAfter' not in self:
            raise SkipException("Cannot get the puppet ca cert expire info")
        self.expire_date = self['notAfter'].datetime
